var tutorial;
var steps =  5;

document.addEventListener('DOMContentLoaded', function() {
    if (typeof(controller) !== 'undefined') {
        steps = controller.numberOfSteps();
    }

    if (steps == 5) {
        var $sixSlide = document.querySelector('[data-slide="6"]');
        var $sixPagination = document.querySelectorAll('[data-to-page]')[5];
        document.querySelector('.wrapper').removeChild($sixSlide);
        document.querySelector('.pagination').removeChild($sixPagination);
    }

    tutorial = new Tutorial();
    __setIndex(0);
});

var Tutorial = function() {
    this.$$pagination = document.querySelectorAll('[data-to-page]');
    this.$nextButton = document.querySelector('#next-button');
    this.$$slides = document.querySelectorAll('[data-slide]');
    this.currentIndex = 0;
    this.maxIndex = this.$$pagination.length - 1;
    this.transitionPropery = false;
    this.init();
}

Tutorial.prototype.init = function() {
    var self = this;
    // pagination click
    [].forEach.call(self.$$pagination, function($pagination, index) {
        $pagination.addEventListener('click', function(e) {
            if (index != self.currentIndex) self.goTo(index);
        }, false);
    });

    // next button click
    self.$nextButton.addEventListener('click', function(e) {
        if (self.currentIndex < self.maxIndex) {
            self.goTo(self.currentIndex + 1);
        } else {
            __launch(); // external
        }
    }, false);

    // get supported prefixes
    self.transitionPropery = self.getPrefix().transition;
}

Tutorial.prototype.goTo = function(index) {
    var self = this;
    var animationDirection;

    if (index > self.currentIndex) {
        animationDirection = {
            active_to: 'left',
            new_from: 'right'
        }
    } else {
        animationDirection = {
            active_to: 'right',
            new_from: 'left'
        }
    }
    self.offSlide(index, animationDirection.new_from, true);
    self.offSlide(self.currentIndex, animationDirection.active_to, false);
    setTimeout(function(){
        self.onSlide(index);
    }, 0);

    self.currentIndex = index;

    // pagination
    [].forEach.call(self.$$pagination, function($pagination, index) {
        $pagination.classList.remove('active');
    });

    // toggle next button text
    self.$$pagination[self.currentIndex].classList.add('active');

    if (steps == 5) {
        if (self.currentIndex == self.maxIndex) {
            this.$nextButton.textContent = document.querySelector('#label-close').textContent;
        } else {
            this.$nextButton.textContent = document.querySelector('#label-next').textContent;
        }
    } else {
        if (self.currentIndex == self.maxIndex) {
            this.$nextButton.style.display = 'none';
        } else {
            this.$nextButton.style.display = 'block';
        }
    }
    __setIndex(self.currentIndex); // external
}

Tutorial.prototype.onSlide = function(index) {
    var self = this;
    var $slide = self.$$slides[index];
    self.forceSlide(index, false);
    $slide.classList.remove('push-right');
    $slide.classList.remove('push-left');
    $slide.classList.add('active');
}

Tutorial.prototype.offSlide = function(index, direction, isForced) {
    var self = this;
    var $slide = self.$$slides[index];
    var dirClass = direction == 'left' ? 'push-left' : 'push-right';
    self.forceSlide(index, isForced);
    $slide.classList.remove('active');
    $slide.classList.remove('push-right');
    $slide.classList.remove('push-left');
    $slide.classList.add(dirClass);
}

Tutorial.prototype.forceSlide = function(index, isForced) {
    var self = this;
    var $slide = self.$$slides[index];
    if (isForced) {
        $slide.style[self.transitionPropery] = 'none';
    } else {
        $slide.removeAttribute('style');
    }
}

Tutorial.prototype.getPrefix = function() {
    var el = document.createElement('div');
    var transformProps = 'transition WebkitTransition MozTransition msTransition'.split(' ');
    function support(properties) {
        for (var i = 0; i < properties.length; i++) {
            if (typeof el.style[properties[i]] !== 'undefined') {
                return properties[i];
            }
        }
        return false;
    }

    return {
        transition: support(transformProps)
    }
}

// external calls

function __gotopage( index ){
	if (tutorial && typeof tutorial.goTo == 'function') tutorial.goTo(index);
}

function __setIndex(index) {
    if (typeof(controller) !== 'undefined') controller.selectPage_(index);
}

function __launch() {
    if (typeof(controller) !== 'undefined') controller.launch();
}